@@ -53,6 +53,7 @@ import java.io.IOException;
 import java.io.Writer;
 import java.util.Collections;
 import java.util.List;
+import java.util.Set;
 import org.glassfish.grizzly.comet.CometContext;
 import org.glassfish.grizzly.comet.CometEvent;
 import org.glassfish.grizzly.comet.DefaultCometHandler;
@@ -60,9 +61,9 @@ import org.glassfish.grizzly.http.server.Response;
 import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.drive.DriveAction;
+import com.openexchange.drive.DriveSession;
 import com.openexchange.drive.DriveVersion;
 import com.openexchange.drive.events.DriveEvent;
-import com.openexchange.drive.DriveSession;
 import com.openexchange.drive.json.json.JsonDriveAction;
 import com.openexchange.java.Streams;
 
@@ -77,16 +78,19 @@ public class DriveCometHandler extends DefaultCometHandler<DriveEvent> {
     private static final List<DriveAction<? extends DriveVersion>> EMPTY_ACTIONS = Collections.emptyList();
 
     private final DriveSession session;
+    private final List<String> rootFolderIDs;
     private long initializationTime;
 
     /**
      * Initializes a new {@link DriveCometHandler}.
      *
-     * @param session
+     * @param session The session
+     * @param rootFolderIDs The root folder IDs to listen for changes in
      */
-    public DriveCometHandler(DriveSession session) {
+    public DriveCometHandler(DriveSession session, List<String> rootFolderIDs) {
         super();
         this.session = session;
+        this.rootFolderIDs = rootFolderIDs;
     }
 
     /**
@@ -109,9 +113,14 @@ public class DriveCometHandler extends DefaultCometHandler<DriveEvent> {
             if (CometEvent.Type.NOTIFY == event.getType()) {
                 CometEvent<DriveEvent> driveCometEvent = event;
                 DriveEvent driveEvent = driveCometEvent.attachment();
-                if (null != driveEvent && driveEvent.getContextID() == session.getServerSession().getContextId() &&
-                    driveEvent.getFolderIDs().contains(session.getRootFolderID())) {
-                    write(null != driveEvent ? driveEvent.getActions() : EMPTY_ACTIONS);
+                if (null != driveEvent && driveEvent.getContextID() == session.getServerSession().getContextId()) {
+                    Set<String> folderIDs = driveEvent.getFolderIDs();
+                    if (null != folderIDs && null != rootFolderIDs) {
+                        List<DriveAction<? extends DriveVersion>> actions = driveEvent.getActions(rootFolderIDs);
+                        if (null != actions && 0 < actions.size()) {
+                            write(actions);
+                        }
+                    }
                 }
             }
         } finally {
